package cz.muni.fi.pb162.school;

import java.io.InputStream;
import java.io.OutputStream;

import java.util.Collection;

/**
 * Toto rozhrani reprezentuje katalog studentu. Zaroven 
 * umoznuje katalog ulozit do souboru nebo jej ze souboru 
 * naopak nacist.
 *
 * @author Petr Adamek &lt;xadamek2@fi.muni.cz&gt;
 */
public interface StudentCatalog {
    
    /**
     * Tato metoda ze zadaneho proudu nacte obsah katalogu. Katalog je
     * v proudu (souboru) organizovan tak, ze na kazdem radku je jeden 
     * student, pricemz radek zacina identifikatorem studenta, pak 
     * nasleduje mezera a zbytek radku obsahuje jmeno studenta. Data
     * jsou v proudu ulozena s kodovanim UTF-8. Poradi radku v souboru
     * neni rozhodujici.
     *
     * @param is Vstupni proud, ze ktereho se budou cist data.
     * @throws StudentCatalogException pokud dojde k chybe pri cteni dat z 
     * proudu nebo ma vstupni soubor nespravny format.
     */
    void load(InputStream is) throws StudentCatalogException;
    
    /**
     * Tato metoda obsah katalogu ulozi do daneho vystupniho proudu. 
     * Format proudu je stejny jako u metody load().
     *
     * @param os Vystupni proud, do nejz se ma katalog zapsat.
     * @throws StudentCatalogException pokud dojde k chybe pri zapisu dat do proudu
     */
    void save(OutputStream os) throws StudentCatalogException;
    
    /**
     * Vrati studenta s danym id.
     * @param id Identifikator studenta, ktereho ma metoda vratit.
     * @return instanci tridy reprezentujici studenta s danym identifikatorem 
     * nebo null, pokud takovy student neexistuje.
     */
    Student getStudent(int id);
    
    /**
     * Metoda vytvori noveho studenta s danym jmenem. Student bude 
     * mit pridelen novy identifikator, ktery jeste zadny student
     * v kolekci nema.
     *
     * @param name jmeno noveho studenta
     * @return instanci tridy reprezentujici noveho studenta
     */
    Student newStudent(String name);
    
    /**
     * Vrati kolekci vsech studentu v katalogu. Kolekci neni mozne 
     * modifikovat.
     *
     * @return mnozinu vsech studentu v katalogu
     */
    Collection<Student> getStudents();
    
    /**
     * Smaze vsechny studenty v katalogu.
     */
    void clear();
    
}
